@@ -1,5 +1,5 @@
 use crate::{BitReadStream, BitWriteStream, Endianness, Result};
-use std::mem::size_of;
+use std::borrow::Cow;
 use std::rc::Rc;
 use std::sync::Arc;
 
@@ -89,7 +89,7 @@ macro_rules! impl_write_int {
         impl<E: Endianness> BitWrite<E> for $type {
             #[inline]
             fn write(&self, stream: &mut BitWriteStream<E>) -> Result<()> {
-                stream.write_int::<$type>(*self, size_of::<$type>() * 8)
+                stream.write_int::<$type>(*self, <$type>::BITS as usize)
             }
         }
     };
@@ -200,6 +200,13 @@ impl<T: BitWrite<E>, E: Endianness> BitWrite<E> for Option<T> {
     }
 }
 
+impl<'a, T: BitWrite<E> + ToOwned, E: Endianness> BitWrite<E> for Cow<'a, T> {
+    #[inline]
+    fn write(&self, stream: &mut BitWriteStream<E>) -> Result<()> {
+        self.as_ref().write(stream)
+    }
+}
+
 macro_rules! impl_write_tuple {
     ($($i:tt: $type:ident),*) => {
         impl<'a, E: Endianness, $($type: BitWrite<E>),*> BitWrite<E> for ($($type),*) {
@@ -370,3 +377,10 @@ impl<T: BitWriteSized<E>, E: Endianness> BitWriteSized<E> for Option<T> {
         Ok(())
     }
 }
+
+impl<'a, T: BitWriteSized<E> + ToOwned, E: Endianness> BitWriteSized<E> for Cow<'a, T> {
+    #[inline]
+    fn write_sized(&self, stream: &mut BitWriteStream<E>, len: usize) -> Result<()> {
+        self.as_ref().write_sized(stream, len)
+    }
+}
